'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = _interopDefault(require('prop-types'));

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var style = {
  container: {
    position: 'relative'
  },
  mainImage: {
    width: '100%',
    height: '100%',
    objectFit: 'cover',
    backgroundRepeat: 'no-repeat'
  },
  overlayImage: {
    position: 'absolute',
    objectFit: 'cover',
    backgroundRepeat: 'no-repeat'
  }
};

var Overlay = function (_Component) {
  inherits(Overlay, _Component);

  function Overlay() {
    classCallCheck(this, Overlay);

    var _this = possibleConstructorReturn(this, (Overlay.__proto__ || Object.getPrototypeOf(Overlay)).call(this));

    _this.state = {
      error: false
    };
    return _this;
  }

  createClass(Overlay, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      var _props = this.props,
          url = _props.url,
          overlayUrl = _props.overlayUrl;

      if ((typeof url === 'string' || url instanceof String) && (typeof overlayUrl === 'string' || overlayUrl instanceof String)) {
        this.setState({
          error: false
        });
      } else {
        this.setState({
          error: true
        });
      }
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps() {}
  }, {
    key: 'overlayPosition',
    value: function overlayPosition() {
      var position = this.props.position;

      switch (position) {
        case 'topLeft':
          return {
            top: '10px',
            left: '10px'
          };
        case 'topRight':
          return {
            top: '10px',
            right: '10px'
          };
        case 'bottomLeft':
          return {
            bottom: '10px',
            left: '10px'
          };
        default:
          return {
            bottom: '10px',
            right: '10px'
          };
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var container = style.container,
          mainImage = style.mainImage,
          overlayImage = style.overlayImage;
      var error = this.state.error;
      var _props2 = this.props,
          url = _props2.url,
          imageHeight = _props2.imageHeight,
          imageWidth = _props2.imageWidth,
          overlayHeight = _props2.overlayHeight,
          overlayWidth = _props2.overlayWidth,
          position = _props2.position,
          overlayUrl = _props2.overlayUrl;


      if (error) {
        return React__default.createElement(
          'p',
          null,
          'URL for main image and overlay required'
        );
      }

      return React__default.createElement(
        'div',
        {
          style: _extends({}, container, {
            height: imageHeight,
            width: imageWidth
          })
        },
        React__default.createElement('img', {
          src: url,
          alt: 'main',
          style: _extends({}, mainImage, {
            backgroundImage: 'url("' + url + '")'
          })
        }),
        React__default.createElement('img', {
          src: overlayUrl,
          alt: 'overlay',
          style: _extends({}, overlayImage, {
            height: overlayHeight,
            width: overlayWidth
          }, this.overlayPosition(position))
        })
      );
    }
  }]);
  return Overlay;
}(React.Component);

Overlay.propTypes = {
  url: PropTypes.string.isRequired,
  overlayUrl: PropTypes.string.isRequired,
  imageHeight: PropTypes.number,
  imageWidth: PropTypes.number,
  overlayHeight: PropTypes.number,
  overlayWidth: PropTypes.number,
  position: PropTypes.string
};
Overlay.defaultProps = {
  imageHeight: 250,
  imageWidth: 250,
  overlayHeight: 30,
  overlayWidth: 30,
  position: null
};

module.exports = Overlay;
//# sourceMappingURL=index.js.map
